@@ -60,20 +60,65 @@ misc_create_menu (MiscCreateMenuEntry *entries,
             g_free (path);
           }
           break;
-        case MISC_CREATE_MENU_ITEM:
-        case MISC_CREATE_MENU_SEPARATOR:
-        case MISC_CREATE_MENU_STOCK:
+        default:
           {
             gchar *path, *p;
             gint j;
 
-            entries[i].widget = (entries[i].menu_type & MISC_CREATE_MENU_MASK)
-                                                    == MISC_CREATE_MENU_STOCK
-                    ? gtk_image_menu_item_new_from_stock (entries[i].name,
-                                        entries[i].accel ? NULL : accel_group)
-                    : entries[i].name
-                        ? gtk_menu_item_new_with_mnemonic (_(entries[i].name))
-                        : gtk_separator_menu_item_new ();
+            switch (entries[i].menu_type & MISC_CREATE_MENU_MASK)
+              {
+                case MISC_CREATE_MENU_STOCK:
+                  if (entries[i].menu_type & MISC_CREATE_MENU_NOIMAGE)
+                    {
+                      GtkStockItem stock_item;
+
+                      gtk_stock_lookup (entries[i].name, &stock_item);
+                      entries[i].widget = gtk_image_menu_item_new_with_mnemonic
+                                                            (stock_item.label);
+                    }
+                  else
+                    {
+                      entries[i].widget = gtk_image_menu_item_new_from_stock
+                                        (entries[i].name,
+                                        entries[i].accel ? NULL : accel_group);
+                    }
+                  break;
+                case MISC_CREATE_MENU_ITEM:
+                  if (entries[i].xpm
+                        && !(entries[i].menu_type & MISC_CREATE_MENU_NOIMAGE))
+                    {
+                      GdkPixbuf *pixbuf;
+
+                      entries[i].widget = gtk_image_menu_item_new_with_mnemonic
+                                                        (_(entries[i].name));
+                      pixbuf = gdk_pixbuf_new_from_xpm_data (entries[i].xpm);
+                      gtk_image_menu_item_set_image
+                                    (GTK_IMAGE_MENU_ITEM (entries[i].widget),
+                                        gtk_image_new_from_pixbuf (pixbuf));
+                      g_object_unref (pixbuf);
+                    }
+                  else
+                    {
+                      entries[i].widget = gtk_menu_item_new_with_mnemonic
+                                                        (_(entries[i].name));
+                    }
+                  break;
+                case MISC_CREATE_MENU_CHECK:
+                  entries[i].widget = gtk_check_menu_item_new_with_mnemonic
+                                                        (_(entries[i].name));
+                  break;
+                case MISC_CREATE_MENU_RADIO:
+                  entries[i].widget = gtk_radio_menu_item_new_with_mnemonic
+                        (i > 0
+                        && (entries[i - 1].menu_type & MISC_CREATE_MENU_MASK)
+                                                     == MISC_CREATE_MENU_RADIO
+                            ? gtk_radio_menu_item_get_group
+                                (GTK_RADIO_MENU_ITEM (entries[i - 1].widget))
+                            : NULL, _(entries[i].name));
+                  break;
+                default:
+                  entries[i].widget = gtk_separator_menu_item_new ();
+              }
             if (entries[i].menu_type & MISC_CREATE_MENU_ELLIPSIS)
               {
                 gchar *mnemonic;
@@ -107,8 +152,15 @@ misc_create_menu (MiscCreateMenuEntry *entries,
                                         GTK_ACCEL_VISIBLE | GTK_ACCEL_LOCKED);
               }
             if (entries[i].func)
-              g_signal_connect (G_OBJECT (entries[i].widget), "activate",
+              g_signal_connect (G_OBJECT (entries[i].widget),
+                            (entries[i].menu_type & MISC_CREATE_MENU_MASK)
+                                                    == MISC_CREATE_MENU_CHECK
+                            || (entries[i].menu_type & MISC_CREATE_MENU_MASK)
+                                                    == MISC_CREATE_MENU_RADIO
+                                                    ? "toggled" : "activate",
                         G_CALLBACK (entries[i].func), entries[i].user_data);
+            if (entries[i].menu_type & MISC_CREATE_MENU_DISABLE)
+              gtk_widget_set_sensitive (entries[i].widget, FALSE);
           }
       }
 }
@@ -736,7 +788,7 @@ misc_str_to_array (gsize          *size,
 {
   gchar *p;
   gpointer array = NULL;
-  gint i, j, value;
+  gint i, j;
 
   if (!size)
     return NULL;
@@ -748,15 +800,28 @@ misc_str_to_array (gsize          *size,
   for (i = 0; p[i] != '\0'; i++)
     {
       for (j = 0; j < radix; j++)
-        if (p[i] == hex[j])
+        if (g_ascii_toupper (p[i]) == hex[j])
           break;
       if (j >= radix)
-        p[i] = '\0';
+        p[i] = ' ';
     }
-  p[i + 1] = '\0';
+  i = j = 0;
+  while (p[i] != '\0')
+    if (p[i] == ' ')
+      {
+        if (p[++i] != ' ')
+          p[j++] = '\0';
+      }
+    else
+      {
+        p[j++] = p[i++];
+      }
+  p[j] = p[j + 1] = '\0';
   i = 0;
   while (p[i] != '\0')
     {
+      gint value;
+
       if (!misc_str_to_val (&value, p + i, radix, flag))
         {
           g_free (p);
