@@ -1,6 +1,6 @@
 /*
     orzconf
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,10 +14,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "orzconf.h"
 #include "orzhistory.h"
+#include "misc/misc.h"
 #include <gdk/gdkkeysyms.h>
 
 
@@ -77,9 +78,9 @@ orz_conf_class_init (OrzConfClass *klass)
   GtkWidgetClass *widget_class;
   GtkBindingSet *binding_set;
 
-  gobject_class = (GObjectClass*) klass;
-  object_class = (GtkObjectClass*) klass;
-  widget_class = (GtkWidgetClass*) klass;
+  gobject_class = (GObjectClass *)klass;
+  object_class = (GtkObjectClass *)klass;
+  widget_class = (GtkWidgetClass *)klass;
 
   parent_class = g_type_class_peek_parent (klass);
 
@@ -146,7 +147,9 @@ orz_conf_delete (GtkWidget *widget,
 static void
 orz_conf_init (OrzConf *conf)
 {
+  gchar *title;
   gint width, height;
+  GtkStockItem stock_item;
   GtkWidget *label0, *label1, *label2;
   GtkWidget *frame0, *frame1, *hbox0, *hbox1, *vbox;
 
@@ -154,14 +157,24 @@ orz_conf_init (OrzConf *conf)
   height = gdk_screen_height ();
 
   /* ja:メインウインドウ */
-  gtk_window_set_title (GTK_WINDOW (conf), _("Configuration"));
+  gtk_stock_lookup (GTK_STOCK_PREFERENCES, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
+  gtk_window_set_title (GTK_WINDOW (conf), title);
+  g_free (title);
   g_signal_connect (G_OBJECT (conf), "delete-event",
                                         G_CALLBACK (orz_conf_delete), NULL);
   /* ja:ボタン */
+#ifdef G_OS_WIN32
   conf->ok_button = gtk_dialog_add_button (GTK_DIALOG (conf),
                                         GTK_STOCK_OK, GTK_RESPONSE_OK);
   conf->cancel_button = gtk_dialog_add_button (GTK_DIALOG (conf),
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+#else /* not G_OS_WIN32 */
+  conf->cancel_button = gtk_dialog_add_button (GTK_DIALOG (conf),
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+  conf->ok_button = gtk_dialog_add_button (GTK_DIALOG (conf),
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
+#endif /* not G_OS_WIN32 */
   /* ja:チェックボタン */
   conf->newfile_check = gtk_check_button_new_with_mnemonic (_("_New File"));
   conf->second_check  = gtk_check_button_new_with_mnemonic (_("_Open Window"));
@@ -277,7 +290,7 @@ orz_conf_init (OrzConf *conf)
 ******************************************************************************/
 /*  ja:新規作成
     RET,ウィジェット                                                        */
-GtkWidget*
+GtkWidget *
 orz_conf_new (void)
 {
   return GTK_WIDGET (g_object_new (ORZ_TYPE_CONF, NULL));
