@@ -270,8 +270,13 @@ merge_dialog (void)
                             (_("Merge"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+#ifdef G_OS_WIN32
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#else /* not G_OS_WIN32 */
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK, GTK_RESPONSE_OK,
+#endif /* not G_OS_WIN32 */
                             NULL);
   g_signal_connect (G_OBJECT (mrgdlg.dialog), "key-press-event",
                                     G_CALLBACK (misc_dialog_key_press), NULL);
@@ -426,9 +431,9 @@ merge_dialog (void)
                     {
                       AviEdit *avi_edit_tmp;
 
-                      avi_edit_tmp = avi_clone (vmaid->avi_edit[j]);
-                      if (!avi_paste (avi_edit[j], avi_length (avi_edit[j]),
-                                                                avi_edit_tmp))
+                      avi_edit_tmp = avi_edit_dup (vmaid->avi_edit[j]);
+                      if (!avi_edit_paste (avi_edit[j],
+                                avi_edit_length (avi_edit[j]), avi_edit_tmp))
                         {
                           GtkWidget *dialog;
 
@@ -437,22 +442,23 @@ merge_dialog (void)
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("AVI Paste Error"));
-                          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                          g_signal_connect (G_OBJECT (dialog),
+                                    "key-press-event",
                                     G_CALLBACK (misc_dialog_key_press), NULL);
                           gtk_dialog_run (GTK_DIALOG (dialog));
                           gtk_widget_destroy (dialog);
                           for (i = 0; i < 2; i++)
                             {
-                              avi_release (avi_edit[i]);
+                              avi_edit_close (avi_edit[i]);
                               avi_edit[i] = NULL;
                             }
-                          avi_release (avi_edit_tmp);
+                          avi_edit_close (avi_edit_tmp);
                           goto loop;
                         }
                     }
                   else
                     {
-                      avi_edit[j] = avi_clone (vmaid->avi_edit[j]);
+                      avi_edit[j] = avi_edit_dup (vmaid->avi_edit[j]);
                     }
                 }
           }
@@ -464,10 +470,10 @@ merge_dialog (void)
       if (vmaid->avi_edit[0])
         {
           size_set_scale (default_view, &vmaid->width, &vmaid->height,
-                                        avi_get_width (vmaid->avi_edit[0]),
-                                        avi_get_height (vmaid->avi_edit[0]));
-          vmaid->rate = avi_get_rate (vmaid->avi_edit[0]);
-          vmaid->scale = avi_get_scale (vmaid->avi_edit[0]);
+                                    avi_edit_get_width (vmaid->avi_edit[0]),
+                                    avi_edit_get_height (vmaid->avi_edit[0]));
+          vmaid->rate = avi_edit_get_rate (vmaid->avi_edit[0]);
+          vmaid->scale = avi_edit_get_scale (vmaid->avi_edit[0]);
         }
       else
         {
