@@ -58,11 +58,11 @@ GObject *clipboard;                 /* ja:クリップボード */
 GObject *history;                   /* ja:ファイルの履歴 */
 GdkBitmap *bitmap0;                 /* ja:波背景 */
 GdkBitmap *bitmap1;                 /* ja:網背景 */
+GtkPositionType n_pos = GTK_POS_TOP;/* ja:ノートブックの位置 */
 GtkWidget *window;                  /* ja:ウインドウ */
 GtkWidget *mdi;                     /* en:MDI */
 GtkWidget *tview;                   /* ja:リストボックス */
 GtkWidget *status;                  /* ja:ステータスウインドウ */
-GtkPositionType n_pos = GTK_POS_TOP;/* ja:ノートブックの位置 */
 GdkFont *system_font = NULL;
 gint system_font_height;            /* ja:フォントの高さ */
 gint system_font_ascent;            /* ja:フォントのアクセントの高さ */
@@ -176,7 +176,7 @@ main (int   argc,
       char *argv[])
 {
   gboolean *arg_files, success[4];
-  gchar *key, *utf8str, *data, *user_config = NULL;
+  gchar *user_config = NULL;
 #if ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
   LPITEMIDLIST pidl = NULL;
 #endif /* ! GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
@@ -186,7 +186,6 @@ main (int   argc,
   gchar *temp;
 # endif /* GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32) */
 #endif /* not LOCALEDIR */
-  gsize length;
   gint i, count = 0, license = -1;
   GKeyFile *key_file;
   GList *glist;
@@ -282,7 +281,7 @@ main (int   argc,
       if (SHGetPathFromIDList (pidl, szPath))
 #  ifdef UNICODE
         {
-          gchar *dir;
+          gchar *dir, *utf8str;
 
           utf8str = g_utf16_to_utf8 (szPath, -1, NULL, NULL, NULL);
           dir = g_filename_from_utf8 (utf8str, -1, NULL, NULL, NULL);
@@ -308,6 +307,8 @@ main (int   argc,
   key_file = g_key_file_new ();
   if (g_key_file_load_from_file (key_file, user_config, G_KEY_FILE_NONE, NULL))
     {
+      gchar *utf8str;
+
       license = g_key_file_get_integer (key_file, "vmaid", "license", NULL);
       orz_history_set_num (ORZ_HISTORY (history),
                 g_key_file_get_integer (key_file, "vmaid", "history", NULL));
@@ -337,6 +338,8 @@ main (int   argc,
       /* ja:ファイルの履歴 */
       for (i = orz_history_get_num (ORZ_HISTORY (history)) - 1; i >= 0; i--)
         {
+          gchar *key;
+
           key = g_strdup_printf ("history%d", i);
           utf8str = g_key_file_get_string (key_file, "vmaid", key, NULL);
           g_free (key);
@@ -454,8 +457,15 @@ VMAID_COPYRIGHT_NOTICE"\n"
   accel_group = gtk_accel_group_new ();
   misc_create_menu (menu_entries, accel_group);
   /* ja:ファイルの履歴 */
+  for (i = 0; menu_entries[i].path; i++)
+#if GLIB_CHECK_VERSION(2,2,0)
+    if (g_str_has_prefix (menu_entries[i].path, "/file/"))
+#else /* not GLIB_CHECK_VERSION(2,2,0) */
+    if (g_strncmp (menu_entries[i].path, "/file/", 6) == 0)
+#endif /* not GLIB_CHECK_VERSION(2,2,0) */
+      count++;
   orz_history_set_menu (ORZ_HISTORY (history),
-                        misc_find_menu (menu_entries, "/file/"), MENUFILE - 2);
+                        misc_find_menu (menu_entries, "/file/"), count - 3);
   g_signal_connect (ORZ_HISTORY (history), "activate",
                             G_CALLBACK (signal_activate_menu_history), NULL);
   /* ja:ウインドウメニュー */
@@ -607,9 +617,9 @@ VMAID_COPYRIGHT_NOTICE"\n"
 
   /* ja:ピクスマップ */
   pixmap = gdk_pixmap_create_from_xpm_d (window->window, &bitmap0, NULL, xpm0);
-  gdk_pixmap_unref (pixmap);
+  g_object_unref (pixmap);
   pixmap = gdk_pixmap_create_from_xpm_d (window->window, &bitmap1, NULL, xpm1);
-  gdk_pixmap_unref (pixmap);
+  g_object_unref (pixmap);
 
   /* ja:システム色 */
   style = gtk_widget_get_style (text);
@@ -635,6 +645,7 @@ VMAID_COPYRIGHT_NOTICE"\n"
     }
 
   /* ja:新規ウインドウ */
+  count = 0;
   for (i = 1; i < argc; i++)
     if (arg_files[i])
       {
@@ -666,71 +677,85 @@ VMAID_COPYRIGHT_NOTICE"\n"
   gdk_threads_leave ();
 #endif /* USE_THREAD */
 
-  gdk_bitmap_unref (bitmap0);
-  gdk_bitmap_unref (bitmap1);
+  g_object_unref (bitmap0);
+  g_object_unref (bitmap1);
 
   /* ja:レジストリに書き込む */
-  key_file = g_key_file_new ();
-  g_key_file_load_from_file (key_file, user_config, G_KEY_FILE_NONE, NULL);
-  g_key_file_set_integer (key_file, "vmaid", "license", license);
-  g_key_file_set_integer (key_file, "vmaid", "history",
+  if (user_config)
+    {
+      gsize length;
+      gchar *data;
+
+      key_file = g_key_file_new ();
+      g_key_file_load_from_file (key_file, user_config, G_KEY_FILE_NONE, NULL);
+      g_key_file_set_integer (key_file, "vmaid", "license", license);
+      g_key_file_set_integer (key_file, "vmaid", "history",
                                 orz_history_get_num (ORZ_HISTORY (history)));
-  g_key_file_set_boolean (key_file, "vmaid", "addext", addext);
-  g_key_file_set_boolean (key_file, "vmaid", "newfile", newfile);
-  g_key_file_set_boolean (key_file, "vmaid", "second", second);
-  g_key_file_set_integer (key_file, "vmaid", "def_width", def_width);
-  g_key_file_set_integer (key_file, "vmaid", "def_height", def_height);
-  g_key_file_set_integer (key_file, "vmaid", "n_pos", n_pos);
-  g_key_file_set_boolean (key_file, "vmaid", "ratio", default_ratio);
-  g_key_file_set_boolean (key_file, "vmaid", "merge", file_merge);
-  g_key_file_set_integer (key_file, "vmaid", "view", default_view);
-  g_key_file_set_integer (key_file, "vmaid", "rate", default_rate);
-  g_key_file_set_boolean (key_file, "vmaid", "selfrm", default_selfrm);
-  if (open_path)
-    {
-      utf8str = g_filename_to_utf8 (open_path, -1, NULL, NULL, NULL);
-      if (utf8str)
+      g_key_file_set_boolean (key_file, "vmaid", "addext", addext);
+      g_key_file_set_boolean (key_file, "vmaid", "newfile", newfile);
+      g_key_file_set_boolean (key_file, "vmaid", "second", second);
+      g_key_file_set_integer (key_file, "vmaid", "def_width", def_width);
+      g_key_file_set_integer (key_file, "vmaid", "def_height", def_height);
+      g_key_file_set_integer (key_file, "vmaid", "n_pos", n_pos);
+      g_key_file_set_boolean (key_file, "vmaid", "ratio", default_ratio);
+      g_key_file_set_boolean (key_file, "vmaid", "merge", file_merge);
+      g_key_file_set_integer (key_file, "vmaid", "view", default_view);
+      g_key_file_set_integer (key_file, "vmaid", "rate", default_rate);
+      g_key_file_set_boolean (key_file, "vmaid", "selfrm", default_selfrm);
+      if (open_path)
         {
-          g_key_file_set_string (key_file, "vmaid", "openpath", utf8str);
-          g_free (utf8str);
+          gchar *utf8str;
+
+          utf8str = g_filename_to_utf8 (open_path, -1, NULL, NULL, NULL);
+          if (utf8str)
+            {
+              g_key_file_set_string (key_file, "vmaid", "openpath", utf8str);
+              g_free (utf8str);
+            }
         }
-    }
-  if (save_path)
-    {
-      utf8str = g_filename_to_utf8 (save_path, -1, NULL, NULL, NULL);
-      if (utf8str)
+      if (save_path)
         {
-          g_key_file_set_string (key_file, "vmaid", "savepath", utf8str);
-          g_free (utf8str);
+          gchar *utf8str;
+
+          utf8str = g_filename_to_utf8 (save_path, -1, NULL, NULL, NULL);
+          if (utf8str)
+            {
+              g_key_file_set_string (key_file, "vmaid", "savepath", utf8str);
+              g_free (utf8str);
+            }
         }
-    }
-  /* ja:ファイルの履歴 */
-  glist = orz_history_get_file (ORZ_HISTORY (history));
-  for (i = 0; i < g_list_length (glist); i++)
-    {
-      key = g_strdup_printf ("history%d", i);
-      utf8str = g_filename_to_utf8 (g_list_nth_data (glist, i), -1,
+      /* ja:ファイルの履歴 */
+      glist = orz_history_get_file (ORZ_HISTORY (history));
+      for (i = 0; i < g_list_length (glist); i++)
+        {
+          gchar *key, *utf8str;
+
+          key = g_strdup_printf ("history%d", i);
+          utf8str = g_filename_to_utf8 (g_list_nth_data (glist, i), -1,
                                                             NULL, NULL, NULL);
-      if (utf8str)
+          if (utf8str)
+            {
+              g_key_file_set_string (key_file, "vmaid", key, utf8str);
+              g_free (utf8str);
+            }
+          g_free (key);
+        }
+      g_list_free (glist);
+      while (i <= ORZ_HISTORY_NUM_MAX)
         {
-          g_key_file_set_string (key_file, "vmaid", key, utf8str);
-          g_free (utf8str);
+          gchar *key;
+
+          key = g_strdup_printf ("history%d", i++);
+          g_key_file_remove_key (key_file, "vmaid", key, NULL);
+          g_free (key);
+        }
+      data = g_key_file_to_data (key_file, &length, NULL);
+      g_key_file_free (key_file);
+      if (data)
+        {
+          fileio_save (user_config, data, length);
+          g_free (data);
         }
-      g_free (key);
-    }
-  g_list_free (glist);
-  while (i <= ORZ_HISTORY_NUM_MAX)
-    {
-      key = g_strdup_printf ("history%d", i++);
-      g_key_file_remove_key (key_file, "vmaid", key, NULL);
-      g_free (key);
-    }
-  data = g_key_file_to_data (key_file, &length, NULL);
-  g_key_file_free (key_file);
-  if (data)
-    {
-      fileio_save (user_config, data, length);
-      g_free (data);
     }
 
   gdk_font_unref (system_font);
